pub struct CompositeAlphaFlags(/* private fields */);Available on crate feature
VK_KHR_surface only.Expand description
Alpha compositing modes supported on a device
Implementations
Sourceimpl CompositeAlphaFlags
impl CompositeAlphaFlags
Sourceimpl CompositeAlphaFlags
impl CompositeAlphaFlags
Sourcepub const OPAQUE: Self
pub const OPAQUE: Self
The alpha channel, if it exists, of the image is ignored in the compositing process
Sourcepub const PRE_MULTIPLIED: Self
pub const PRE_MULTIPLIED: Self
The alpha channel, if it exists, of the images is respected in the compositing process. The non-alpha channels of the image are expected to already be multiplied by the alpha channel by the application
Sourcepub const POST_MULTIPLIED: Self
pub const POST_MULTIPLIED: Self
The alpha channel, if it exists, of the images is respected in the compositing process. The non-alpha channels of the image are not expected to already be multiplied by the alpha channel by the application; instead, the compositor will multiply the non-alpha channels of the image by the alpha channel during compositing