#[repr(transparent)]pub struct SurfaceCapabilities(pub VkSurfaceCapabilitiesKHR);Available on crate feature
VK_KHR_surface only.Tuple Fields
0: VkSurfaceCapabilitiesKHRImplementations
Sourceimpl SurfaceCapabilities
impl SurfaceCapabilities
Sourcepub const fn supported_transforms(&self) -> SurfaceTransformFlags
pub const fn supported_transforms(&self) -> SurfaceTransformFlags
The presentation transforms supported for the surface
Sourcepub const fn current_transform(&self) -> SurfaceTransformFlags
pub const fn current_transform(&self) -> SurfaceTransformFlags
The surface’s current transform relative to the presentation engine’s natural orientation
Sourcepub const fn supported_composite_alpha(&self) -> CompositeAlphaFlags
pub const fn supported_composite_alpha(&self) -> CompositeAlphaFlags
The alpha compositing modes supported by the presentation engine for the surface
Sourcepub const fn supported_usage_flags(&self) -> ImageUsageFlags
pub const fn supported_usage_flags(&self) -> ImageUsageFlags
The ways the application can use the presentable images of a swapchain