pub trait PipelineCache: VkHandle<Handle = VkPipelineCache> + DeviceChildHandle {
// Provided methods
fn data_len(&self) -> Result<usize> { ... }
fn data_into(
&self,
store: &mut [MaybeUninit<u8>],
) -> Result<ArrayQueryResult<usize>> { ... }
}Provided Methods
Sourcefn data_len(&self) -> Result<usize>
Available on crate feature Implements only.
fn data_len(&self) -> Result<usize>
Implements only.Get the size of the data store from a pipeline cache
Failures
On failure, this command returns
- [
brvk::VK_ERROR_OUT_OF_HOST_MEMORY] - [
brvk::VK_ERROR_OUT_OF_DEVICE_MEMORY]
Sourcefn data_into(
&self,
store: &mut [MaybeUninit<u8>],
) -> Result<ArrayQueryResult<usize>>
Available on crate feature Implements only.
fn data_into( &self, store: &mut [MaybeUninit<u8>], ) -> Result<ArrayQueryResult<usize>>
Implements only.Get the content of the data store from a pipeline cache
Failures
On failure, this command returns
- [
brvk::VK_ERROR_OUT_OF_HOST_MEMORY] - [
brvk::VK_ERROR_OUT_OF_DEVICE_MEMORY]
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".