Trait PipelineCache
Source pub trait PipelineCache: VkHandle<Handle = VkPipelineCache> + DeviceChildHandle {
// Provided methods
fn data_len(&self) -> Result<usize> { ... }
fn data_into(&self, store: &mut [u8]) -> Result<usize> { ... }
}
Available on crate feature Implements only.
Get the size of the data store from a pipeline cache
Failures
On failure, this command returns
Available on crate feature Implements only.
Get the content of the data store from a pipeline cache
Failures
On failure, this command returns