pub trait Swapchain: VkHandle<Handle = VkSwapchainKHR> + DeviceChild {
// Provided methods
fn image_count(&self) -> Result<u32> { ... }
fn images(
&self,
sink: &mut [MaybeUninit<VkImage>],
) -> Result<ArrayQueryResult<u32>> { ... }
fn acquire_full_screen_exclusive_mode(&self) -> Result<()>
where Self::ConcreteDevice: DeviceFullScreenExclusiveExtension { ... }
fn release_full_screen_exclusive_mode(&self) -> Result<()>
where Self::ConcreteDevice: DeviceFullScreenExclusiveExtension { ... }
}Available on crate features
VK_KHR_surface and VK_KHR_swapchain only.Provided Methods
Sourcefn image_count(&self) -> Result<u32>
Available on crate feature Implements only.
fn image_count(&self) -> Result<u32>
Implements only.Obtain a count of the array of presentable images associated with a swapchain
Failures
On failure, this command returns
- [
brvk::VK_ERROR_OUT_OF_HOST_MEMORY] - [
brvk::VK_ERROR_OUT_OF_DEVICE_MEMORY]
Sourcefn images(
&self,
sink: &mut [MaybeUninit<VkImage>],
) -> Result<ArrayQueryResult<u32>>
Available on crate feature Implements only.
fn images( &self, sink: &mut [MaybeUninit<VkImage>], ) -> Result<ArrayQueryResult<u32>>
Implements only.Obtain the array of presentable images associated with a swapchain
Failures
On failure, this command returns
- [
brvk::VK_ERROR_OUT_OF_HOST_MEMORY] - [
brvk::VK_ERROR_OUT_OF_DEVICE_MEMORY]
Sourcefn acquire_full_screen_exclusive_mode(&self) -> Result<()>where
Self::ConcreteDevice: DeviceFullScreenExclusiveExtension,
Available on crate features Implements and VK_EXT_full_screen_exclusive only.
fn acquire_full_screen_exclusive_mode(&self) -> Result<()>where
Self::ConcreteDevice: DeviceFullScreenExclusiveExtension,
Implements and VK_EXT_full_screen_exclusive only.Acquire full-screen exclusive mode for a swapchain.
Failures
On failure, this command returns
brvk::VK_ERROR_OUT_OF_HOST_MEMORYbrvk::VK_ERROR_OUT_OF_DEVICE_MEMORYbrvk::VK_ERROR_INITIALIZATION_FAILEDbrvk::VK_ERROR_SURFACE_LOST_KHR
Sourcefn release_full_screen_exclusive_mode(&self) -> Result<()>where
Self::ConcreteDevice: DeviceFullScreenExclusiveExtension,
Available on crate features Implements and VK_EXT_full_screen_exclusive only.
fn release_full_screen_exclusive_mode(&self) -> Result<()>where
Self::ConcreteDevice: DeviceFullScreenExclusiveExtension,
Implements and VK_EXT_full_screen_exclusive only.Release full-screen exclusive mode from a swapchain.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".